@@ -4,7 +4,8 @@
 # Copyright (C) 1986, 1987, 1988, 1989, 1990, 1991, 1992, 1993, 1994,
 #     1995, 1996, 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004,
 #     2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014,
-#     2015, 2016, 2017 Massachusetts Institute of Technology
+#     2015, 2016, 2017, 2018, 2019 Massachusetts Institute of
+#     Technology
 #
 # This file is part of a gdbm plugin for MIT/GNU Scheme.
 #
@@ -27,11 +28,12 @@
 
 set -e
 : ${MIT_SCHEME_EXE=mit-scheme}
-${MIT_SCHEME_EXE} --prepend-library . --batch-mode <<\EOF
+: ${MIT_SCHEME_FLAGS=}
+${MIT_SCHEME_EXE} --prepend-library . --batch-mode --no-init-file ${MIT_SCHEME_FLAGS} <<\EOF
 (load "compile.scm")
 EOF
 suffix=`echo "(display (microcode-id/operating-system-suffix))" \
-	| ${MIT_SCHEME_EXE} --batch-mode`
+	| ${MIT_SCHEME_EXE} --batch-mode --no-init-file`
 report=gdbm-$suffix.crf
 if [ -s "$report" ]; then
     echo "$0: warning: $report is not empty"
